# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEndpointResult',
    'AwaitableGetEndpointResult',
    'get_endpoint',
    'get_endpoint_output',
]

@pulumi.output_type
class GetEndpointResult:
    """
    A collection of values returned by getEndpoint.
    """
    def __init__(__self__, custom_attributes=None, description=None, group_id=None, id=None, identity_store=None, identity_store_id=None, mac=None, mdm_compliance_status=None, mdm_encrypted=None, mdm_enrolled=None, mdm_imei=None, mdm_jail_broken=None, mdm_manufacturer=None, mdm_model=None, mdm_os=None, mdm_phone_number=None, mdm_pinlock=None, mdm_reachable=None, mdm_serial=None, mdm_server_name=None, name=None, portal_user=None, profile_id=None, static_group_assignment=None, static_group_assignment_defined=None, static_profile_assignment=None, static_profile_assignment_defined=None):
        if custom_attributes and not isinstance(custom_attributes, dict):
            raise TypeError("Expected argument 'custom_attributes' to be a dict")
        pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_store and not isinstance(identity_store, str):
            raise TypeError("Expected argument 'identity_store' to be a str")
        pulumi.set(__self__, "identity_store", identity_store)
        if identity_store_id and not isinstance(identity_store_id, str):
            raise TypeError("Expected argument 'identity_store_id' to be a str")
        pulumi.set(__self__, "identity_store_id", identity_store_id)
        if mac and not isinstance(mac, str):
            raise TypeError("Expected argument 'mac' to be a str")
        pulumi.set(__self__, "mac", mac)
        if mdm_compliance_status and not isinstance(mdm_compliance_status, bool):
            raise TypeError("Expected argument 'mdm_compliance_status' to be a bool")
        pulumi.set(__self__, "mdm_compliance_status", mdm_compliance_status)
        if mdm_encrypted and not isinstance(mdm_encrypted, bool):
            raise TypeError("Expected argument 'mdm_encrypted' to be a bool")
        pulumi.set(__self__, "mdm_encrypted", mdm_encrypted)
        if mdm_enrolled and not isinstance(mdm_enrolled, bool):
            raise TypeError("Expected argument 'mdm_enrolled' to be a bool")
        pulumi.set(__self__, "mdm_enrolled", mdm_enrolled)
        if mdm_imei and not isinstance(mdm_imei, str):
            raise TypeError("Expected argument 'mdm_imei' to be a str")
        pulumi.set(__self__, "mdm_imei", mdm_imei)
        if mdm_jail_broken and not isinstance(mdm_jail_broken, bool):
            raise TypeError("Expected argument 'mdm_jail_broken' to be a bool")
        pulumi.set(__self__, "mdm_jail_broken", mdm_jail_broken)
        if mdm_manufacturer and not isinstance(mdm_manufacturer, str):
            raise TypeError("Expected argument 'mdm_manufacturer' to be a str")
        pulumi.set(__self__, "mdm_manufacturer", mdm_manufacturer)
        if mdm_model and not isinstance(mdm_model, str):
            raise TypeError("Expected argument 'mdm_model' to be a str")
        pulumi.set(__self__, "mdm_model", mdm_model)
        if mdm_os and not isinstance(mdm_os, str):
            raise TypeError("Expected argument 'mdm_os' to be a str")
        pulumi.set(__self__, "mdm_os", mdm_os)
        if mdm_phone_number and not isinstance(mdm_phone_number, str):
            raise TypeError("Expected argument 'mdm_phone_number' to be a str")
        pulumi.set(__self__, "mdm_phone_number", mdm_phone_number)
        if mdm_pinlock and not isinstance(mdm_pinlock, bool):
            raise TypeError("Expected argument 'mdm_pinlock' to be a bool")
        pulumi.set(__self__, "mdm_pinlock", mdm_pinlock)
        if mdm_reachable and not isinstance(mdm_reachable, bool):
            raise TypeError("Expected argument 'mdm_reachable' to be a bool")
        pulumi.set(__self__, "mdm_reachable", mdm_reachable)
        if mdm_serial and not isinstance(mdm_serial, str):
            raise TypeError("Expected argument 'mdm_serial' to be a str")
        pulumi.set(__self__, "mdm_serial", mdm_serial)
        if mdm_server_name and not isinstance(mdm_server_name, str):
            raise TypeError("Expected argument 'mdm_server_name' to be a str")
        pulumi.set(__self__, "mdm_server_name", mdm_server_name)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if portal_user and not isinstance(portal_user, str):
            raise TypeError("Expected argument 'portal_user' to be a str")
        pulumi.set(__self__, "portal_user", portal_user)
        if profile_id and not isinstance(profile_id, str):
            raise TypeError("Expected argument 'profile_id' to be a str")
        pulumi.set(__self__, "profile_id", profile_id)
        if static_group_assignment and not isinstance(static_group_assignment, bool):
            raise TypeError("Expected argument 'static_group_assignment' to be a bool")
        pulumi.set(__self__, "static_group_assignment", static_group_assignment)
        if static_group_assignment_defined and not isinstance(static_group_assignment_defined, bool):
            raise TypeError("Expected argument 'static_group_assignment_defined' to be a bool")
        pulumi.set(__self__, "static_group_assignment_defined", static_group_assignment_defined)
        if static_profile_assignment and not isinstance(static_profile_assignment, bool):
            raise TypeError("Expected argument 'static_profile_assignment' to be a bool")
        pulumi.set(__self__, "static_profile_assignment", static_profile_assignment)
        if static_profile_assignment_defined and not isinstance(static_profile_assignment_defined, bool):
            raise TypeError("Expected argument 'static_profile_assignment_defined' to be a bool")
        pulumi.set(__self__, "static_profile_assignment_defined", static_profile_assignment_defined)

    @_builtins.property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> Mapping[str, _builtins.str]:
        """
        Custom Attributes
        """
        return pulumi.get(self, "custom_attributes")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.str:
        """
        Identity Group ID
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="identityStore")
    def identity_store(self) -> _builtins.str:
        """
        Identity Store
        """
        return pulumi.get(self, "identity_store")

    @_builtins.property
    @pulumi.getter(name="identityStoreId")
    def identity_store_id(self) -> _builtins.str:
        """
        Identity Store Id
        """
        return pulumi.get(self, "identity_store_id")

    @_builtins.property
    @pulumi.getter
    def mac(self) -> _builtins.str:
        """
        MAC address of the endpoint
        """
        return pulumi.get(self, "mac")

    @_builtins.property
    @pulumi.getter(name="mdmComplianceStatus")
    def mdm_compliance_status(self) -> _builtins.bool:
        """
        Mdm Compliance Status
        """
        return pulumi.get(self, "mdm_compliance_status")

    @_builtins.property
    @pulumi.getter(name="mdmEncrypted")
    def mdm_encrypted(self) -> _builtins.bool:
        """
        Mdm Encrypted
        """
        return pulumi.get(self, "mdm_encrypted")

    @_builtins.property
    @pulumi.getter(name="mdmEnrolled")
    def mdm_enrolled(self) -> _builtins.bool:
        """
        Mdm Enrolled
        """
        return pulumi.get(self, "mdm_enrolled")

    @_builtins.property
    @pulumi.getter(name="mdmImei")
    def mdm_imei(self) -> _builtins.str:
        """
        Mdm IMEI
        """
        return pulumi.get(self, "mdm_imei")

    @_builtins.property
    @pulumi.getter(name="mdmJailBroken")
    def mdm_jail_broken(self) -> _builtins.bool:
        """
        Mdm JailBroken
        """
        return pulumi.get(self, "mdm_jail_broken")

    @_builtins.property
    @pulumi.getter(name="mdmManufacturer")
    def mdm_manufacturer(self) -> _builtins.str:
        """
        Mdm Manufacturer
        """
        return pulumi.get(self, "mdm_manufacturer")

    @_builtins.property
    @pulumi.getter(name="mdmModel")
    def mdm_model(self) -> _builtins.str:
        """
        Mdm Model
        """
        return pulumi.get(self, "mdm_model")

    @_builtins.property
    @pulumi.getter(name="mdmOs")
    def mdm_os(self) -> _builtins.str:
        """
        Mdm OS
        """
        return pulumi.get(self, "mdm_os")

    @_builtins.property
    @pulumi.getter(name="mdmPhoneNumber")
    def mdm_phone_number(self) -> _builtins.str:
        """
        Mdm PhoneNumber
        """
        return pulumi.get(self, "mdm_phone_number")

    @_builtins.property
    @pulumi.getter(name="mdmPinlock")
    def mdm_pinlock(self) -> _builtins.bool:
        """
        Mdm Pinlock
        """
        return pulumi.get(self, "mdm_pinlock")

    @_builtins.property
    @pulumi.getter(name="mdmReachable")
    def mdm_reachable(self) -> _builtins.bool:
        """
        Mdm Reachable
        """
        return pulumi.get(self, "mdm_reachable")

    @_builtins.property
    @pulumi.getter(name="mdmSerial")
    def mdm_serial(self) -> _builtins.str:
        """
        Mdm Serial
        """
        return pulumi.get(self, "mdm_serial")

    @_builtins.property
    @pulumi.getter(name="mdmServerName")
    def mdm_server_name(self) -> _builtins.str:
        """
        Mdm Server Name
        """
        return pulumi.get(self, "mdm_server_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the endpoint
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="portalUser")
    def portal_user(self) -> _builtins.str:
        """
        Portal User
        """
        return pulumi.get(self, "portal_user")

    @_builtins.property
    @pulumi.getter(name="profileId")
    def profile_id(self) -> _builtins.str:
        """
        Profile ID
        """
        return pulumi.get(self, "profile_id")

    @_builtins.property
    @pulumi.getter(name="staticGroupAssignment")
    def static_group_assignment(self) -> _builtins.bool:
        """
        Static Group Assignment
        """
        return pulumi.get(self, "static_group_assignment")

    @_builtins.property
    @pulumi.getter(name="staticGroupAssignmentDefined")
    def static_group_assignment_defined(self) -> _builtins.bool:
        """
        staticGroupAssignmentDefined
        """
        return pulumi.get(self, "static_group_assignment_defined")

    @_builtins.property
    @pulumi.getter(name="staticProfileAssignment")
    def static_profile_assignment(self) -> _builtins.bool:
        """
        Static Profile Assignment
        """
        return pulumi.get(self, "static_profile_assignment")

    @_builtins.property
    @pulumi.getter(name="staticProfileAssignmentDefined")
    def static_profile_assignment_defined(self) -> _builtins.bool:
        """
        Static Profile Assignment Defined
        """
        return pulumi.get(self, "static_profile_assignment_defined")


class AwaitableGetEndpointResult(GetEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointResult(
            custom_attributes=self.custom_attributes,
            description=self.description,
            group_id=self.group_id,
            id=self.id,
            identity_store=self.identity_store,
            identity_store_id=self.identity_store_id,
            mac=self.mac,
            mdm_compliance_status=self.mdm_compliance_status,
            mdm_encrypted=self.mdm_encrypted,
            mdm_enrolled=self.mdm_enrolled,
            mdm_imei=self.mdm_imei,
            mdm_jail_broken=self.mdm_jail_broken,
            mdm_manufacturer=self.mdm_manufacturer,
            mdm_model=self.mdm_model,
            mdm_os=self.mdm_os,
            mdm_phone_number=self.mdm_phone_number,
            mdm_pinlock=self.mdm_pinlock,
            mdm_reachable=self.mdm_reachable,
            mdm_serial=self.mdm_serial,
            mdm_server_name=self.mdm_server_name,
            name=self.name,
            portal_user=self.portal_user,
            profile_id=self.profile_id,
            static_group_assignment=self.static_group_assignment,
            static_group_assignment_defined=self.static_group_assignment_defined,
            static_profile_assignment=self.static_profile_assignment,
            static_profile_assignment_defined=self.static_profile_assignment_defined)


def get_endpoint(id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointResult:
    """
    This data source can read the Endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the endpoint
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult).value

    return AwaitableGetEndpointResult(
        custom_attributes=pulumi.get(__ret__, 'custom_attributes'),
        description=pulumi.get(__ret__, 'description'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        identity_store=pulumi.get(__ret__, 'identity_store'),
        identity_store_id=pulumi.get(__ret__, 'identity_store_id'),
        mac=pulumi.get(__ret__, 'mac'),
        mdm_compliance_status=pulumi.get(__ret__, 'mdm_compliance_status'),
        mdm_encrypted=pulumi.get(__ret__, 'mdm_encrypted'),
        mdm_enrolled=pulumi.get(__ret__, 'mdm_enrolled'),
        mdm_imei=pulumi.get(__ret__, 'mdm_imei'),
        mdm_jail_broken=pulumi.get(__ret__, 'mdm_jail_broken'),
        mdm_manufacturer=pulumi.get(__ret__, 'mdm_manufacturer'),
        mdm_model=pulumi.get(__ret__, 'mdm_model'),
        mdm_os=pulumi.get(__ret__, 'mdm_os'),
        mdm_phone_number=pulumi.get(__ret__, 'mdm_phone_number'),
        mdm_pinlock=pulumi.get(__ret__, 'mdm_pinlock'),
        mdm_reachable=pulumi.get(__ret__, 'mdm_reachable'),
        mdm_serial=pulumi.get(__ret__, 'mdm_serial'),
        mdm_server_name=pulumi.get(__ret__, 'mdm_server_name'),
        name=pulumi.get(__ret__, 'name'),
        portal_user=pulumi.get(__ret__, 'portal_user'),
        profile_id=pulumi.get(__ret__, 'profile_id'),
        static_group_assignment=pulumi.get(__ret__, 'static_group_assignment'),
        static_group_assignment_defined=pulumi.get(__ret__, 'static_group_assignment_defined'),
        static_profile_assignment=pulumi.get(__ret__, 'static_profile_assignment'),
        static_profile_assignment_defined=pulumi.get(__ret__, 'static_profile_assignment_defined'))
def get_endpoint_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointResult]:
    """
    This data source can read the Endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the endpoint
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult)
    return __ret__.apply(lambda __response__: GetEndpointResult(
        custom_attributes=pulumi.get(__response__, 'custom_attributes'),
        description=pulumi.get(__response__, 'description'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        identity_store=pulumi.get(__response__, 'identity_store'),
        identity_store_id=pulumi.get(__response__, 'identity_store_id'),
        mac=pulumi.get(__response__, 'mac'),
        mdm_compliance_status=pulumi.get(__response__, 'mdm_compliance_status'),
        mdm_encrypted=pulumi.get(__response__, 'mdm_encrypted'),
        mdm_enrolled=pulumi.get(__response__, 'mdm_enrolled'),
        mdm_imei=pulumi.get(__response__, 'mdm_imei'),
        mdm_jail_broken=pulumi.get(__response__, 'mdm_jail_broken'),
        mdm_manufacturer=pulumi.get(__response__, 'mdm_manufacturer'),
        mdm_model=pulumi.get(__response__, 'mdm_model'),
        mdm_os=pulumi.get(__response__, 'mdm_os'),
        mdm_phone_number=pulumi.get(__response__, 'mdm_phone_number'),
        mdm_pinlock=pulumi.get(__response__, 'mdm_pinlock'),
        mdm_reachable=pulumi.get(__response__, 'mdm_reachable'),
        mdm_serial=pulumi.get(__response__, 'mdm_serial'),
        mdm_server_name=pulumi.get(__response__, 'mdm_server_name'),
        name=pulumi.get(__response__, 'name'),
        portal_user=pulumi.get(__response__, 'portal_user'),
        profile_id=pulumi.get(__response__, 'profile_id'),
        static_group_assignment=pulumi.get(__response__, 'static_group_assignment'),
        static_group_assignment_defined=pulumi.get(__response__, 'static_group_assignment_defined'),
        static_profile_assignment=pulumi.get(__response__, 'static_profile_assignment'),
        static_profile_assignment_defined=pulumi.get(__response__, 'static_profile_assignment_defined')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEndpointCustomAttributeResult',
    'AwaitableGetEndpointCustomAttributeResult',
    'get_endpoint_custom_attribute',
    'get_endpoint_custom_attribute_output',
]

@pulumi.output_type
class GetEndpointCustomAttributeResult:
    """
    A collection of values returned by getEndpointCustomAttribute.
    """
    def __init__(__self__, attribute_name=None, attribute_type=None, id=None):
        if attribute_name and not isinstance(attribute_name, str):
            raise TypeError("Expected argument 'attribute_name' to be a str")
        pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_type and not isinstance(attribute_type, str):
            raise TypeError("Expected argument 'attribute_type' to be a str")
        pulumi.set(__self__, "attribute_type", attribute_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> _builtins.str:
        """
        The name of the attribute
        """
        return pulumi.get(self, "attribute_name")

    @_builtins.property
    @pulumi.getter(name="attributeType")
    def attribute_type(self) -> _builtins.str:
        """
        Attribute type
        """
        return pulumi.get(self, "attribute_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")


class AwaitableGetEndpointCustomAttributeResult(GetEndpointCustomAttributeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointCustomAttributeResult(
            attribute_name=self.attribute_name,
            attribute_type=self.attribute_type,
            id=self.id)


def get_endpoint_custom_attribute(id: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointCustomAttributeResult:
    """
    This data source can read the Endpoint Custom Attribute.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_custom_attribute(id="isMobile")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getEndpointCustomAttribute:getEndpointCustomAttribute', __args__, opts=opts, typ=GetEndpointCustomAttributeResult).value

    return AwaitableGetEndpointCustomAttributeResult(
        attribute_name=pulumi.get(__ret__, 'attribute_name'),
        attribute_type=pulumi.get(__ret__, 'attribute_type'),
        id=pulumi.get(__ret__, 'id'))
def get_endpoint_custom_attribute_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointCustomAttributeResult]:
    """
    This data source can read the Endpoint Custom Attribute.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_custom_attribute(id="isMobile")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getEndpointCustomAttribute:getEndpointCustomAttribute', __args__, opts=opts, typ=GetEndpointCustomAttributeResult)
    return __ret__.apply(lambda __response__: GetEndpointCustomAttributeResult(
        attribute_name=pulumi.get(__response__, 'attribute_name'),
        attribute_type=pulumi.get(__response__, 'attribute_type'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEndpointIdentityGroupResult',
    'AwaitableGetEndpointIdentityGroupResult',
    'get_endpoint_identity_group',
    'get_endpoint_identity_group_output',
]

@pulumi.output_type
class GetEndpointIdentityGroupResult:
    """
    A collection of values returned by getEndpointIdentityGroup.
    """
    def __init__(__self__, description=None, id=None, name=None, parent_endpoint_identity_group_id=None, system_defined=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent_endpoint_identity_group_id and not isinstance(parent_endpoint_identity_group_id, str):
            raise TypeError("Expected argument 'parent_endpoint_identity_group_id' to be a str")
        pulumi.set(__self__, "parent_endpoint_identity_group_id", parent_endpoint_identity_group_id)
        if system_defined and not isinstance(system_defined, bool):
            raise TypeError("Expected argument 'system_defined' to be a bool")
        pulumi.set(__self__, "system_defined", system_defined)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the endpoint identity group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="parentEndpointIdentityGroupId")
    def parent_endpoint_identity_group_id(self) -> _builtins.str:
        """
        Parent endpoint identity group ID
        """
        return pulumi.get(self, "parent_endpoint_identity_group_id")

    @_builtins.property
    @pulumi.getter(name="systemDefined")
    def system_defined(self) -> _builtins.bool:
        """
        System defined endpoint identity group
        """
        return pulumi.get(self, "system_defined")


class AwaitableGetEndpointIdentityGroupResult(GetEndpointIdentityGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointIdentityGroupResult(
            description=self.description,
            id=self.id,
            name=self.name,
            parent_endpoint_identity_group_id=self.parent_endpoint_identity_group_id,
            system_defined=self.system_defined)


def get_endpoint_identity_group(id: Optional[_builtins.str] = None,
                                name: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointIdentityGroupResult:
    """
    This data source can read the Endpoint Identity Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_identity_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the endpoint identity group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getEndpointIdentityGroup:getEndpointIdentityGroup', __args__, opts=opts, typ=GetEndpointIdentityGroupResult).value

    return AwaitableGetEndpointIdentityGroupResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        parent_endpoint_identity_group_id=pulumi.get(__ret__, 'parent_endpoint_identity_group_id'),
        system_defined=pulumi.get(__ret__, 'system_defined'))
def get_endpoint_identity_group_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointIdentityGroupResult]:
    """
    This data source can read the Endpoint Identity Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_endpoint_identity_group(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: The name of the endpoint identity group
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getEndpointIdentityGroup:getEndpointIdentityGroup', __args__, opts=opts, typ=GetEndpointIdentityGroupResult)
    return __ret__.apply(lambda __response__: GetEndpointIdentityGroupResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        parent_endpoint_identity_group_id=pulumi.get(__response__, 'parent_endpoint_identity_group_id'),
        system_defined=pulumi.get(__response__, 'system_defined')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLicenseTierStateResult',
    'AwaitableGetLicenseTierStateResult',
    'get_license_tier_state',
    'get_license_tier_state_output',
]

@pulumi.output_type
class GetLicenseTierStateResult:
    """
    A collection of values returned by getLicenseTierState.
    """
    def __init__(__self__, id=None, licenses=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if licenses and not isinstance(licenses, list):
            raise TypeError("Expected argument 'licenses' to be a list")
        pulumi.set(__self__, "licenses", licenses)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def licenses(self) -> Sequence['outputs.GetLicenseTierStateLicenseResult']:
        """
        List of licenses
        """
        return pulumi.get(self, "licenses")


class AwaitableGetLicenseTierStateResult(GetLicenseTierStateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLicenseTierStateResult(
            id=self.id,
            licenses=self.licenses)


def get_license_tier_state(id: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLicenseTierStateResult:
    """
    This data source can read the License Tier State.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.system.get_license_tier_state(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:system/getLicenseTierState:getLicenseTierState', __args__, opts=opts, typ=GetLicenseTierStateResult).value

    return AwaitableGetLicenseTierStateResult(
        id=pulumi.get(__ret__, 'id'),
        licenses=pulumi.get(__ret__, 'licenses'))
def get_license_tier_state_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLicenseTierStateResult]:
    """
    This data source can read the License Tier State.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.system.get_license_tier_state(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:system/getLicenseTierState:getLicenseTierState', __args__, opts=opts, typ=GetLicenseTierStateResult)
    return __ret__.apply(lambda __response__: GetLicenseTierStateResult(
        id=pulumi.get(__response__, 'id'),
        licenses=pulumi.get(__response__, 'licenses')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConditionResult',
    'AwaitableGetConditionResult',
    'get_condition',
    'get_condition_output',
]

@pulumi.output_type
class GetConditionResult:
    """
    A collection of values returned by getCondition.
    """
    def __init__(__self__, attribute_name=None, attribute_value=None, childrens=None, condition_type=None, description=None, dictionary_name=None, dictionary_value=None, id=None, is_negate=None, name=None, operator=None):
        if attribute_name and not isinstance(attribute_name, str):
            raise TypeError("Expected argument 'attribute_name' to be a str")
        pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value and not isinstance(attribute_value, str):
            raise TypeError("Expected argument 'attribute_value' to be a str")
        pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens and not isinstance(childrens, list):
            raise TypeError("Expected argument 'childrens' to be a list")
        pulumi.set(__self__, "childrens", childrens)
        if condition_type and not isinstance(condition_type, str):
            raise TypeError("Expected argument 'condition_type' to be a str")
        pulumi.set(__self__, "condition_type", condition_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dictionary_name and not isinstance(dictionary_name, str):
            raise TypeError("Expected argument 'dictionary_name' to be a str")
        pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value and not isinstance(dictionary_value, str):
            raise TypeError("Expected argument 'dictionary_value' to be a str")
        pulumi.set(__self__, "dictionary_value", dictionary_value)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_negate and not isinstance(is_negate, bool):
            raise TypeError("Expected argument 'is_negate' to be a bool")
        pulumi.set(__self__, "is_negate", is_negate)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if operator and not isinstance(operator, str):
            raise TypeError("Expected argument 'operator' to be a str")
        pulumi.set(__self__, "operator", operator)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> _builtins.str:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @_builtins.property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> _builtins.str:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Sequence['outputs.GetConditionChildrenResult']:
        """
        List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> _builtins.str:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that additional conditions are present under the children attribute.
        """
        return pulumi.get(self, "condition_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> _builtins.str:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @_builtins.property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> _builtins.str:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> _builtins.bool:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def operator(self) -> _builtins.str:
        """
        Equality operator
        """
        return pulumi.get(self, "operator")


class AwaitableGetConditionResult(GetConditionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConditionResult(
            attribute_name=self.attribute_name,
            attribute_value=self.attribute_value,
            childrens=self.childrens,
            condition_type=self.condition_type,
            description=self.description,
            dictionary_name=self.dictionary_name,
            dictionary_value=self.dictionary_value,
            id=self.id,
            is_negate=self.is_negate,
            name=self.name,
            operator=self.operator)


def get_condition(id: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConditionResult:
    """
    This data source can read the Device Admin Condition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_condition(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Condition name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:deviceadmin/getCondition:getCondition', __args__, opts=opts, typ=GetConditionResult).value

    return AwaitableGetConditionResult(
        attribute_name=pulumi.get(__ret__, 'attribute_name'),
        attribute_value=pulumi.get(__ret__, 'attribute_value'),
        childrens=pulumi.get(__ret__, 'childrens'),
        condition_type=pulumi.get(__ret__, 'condition_type'),
        description=pulumi.get(__ret__, 'description'),
        dictionary_name=pulumi.get(__ret__, 'dictionary_name'),
        dictionary_value=pulumi.get(__ret__, 'dictionary_value'),
        id=pulumi.get(__ret__, 'id'),
        is_negate=pulumi.get(__ret__, 'is_negate'),
        name=pulumi.get(__ret__, 'name'),
        operator=pulumi.get(__ret__, 'operator'))
def get_condition_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConditionResult]:
    """
    This data source can read the Device Admin Condition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_condition(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param _builtins.str id: The id of the object
    :param _builtins.str name: Condition name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:deviceadmin/getCondition:getCondition', __args__, opts=opts, typ=GetConditionResult)
    return __ret__.apply(lambda __response__: GetConditionResult(
        attribute_name=pulumi.get(__response__, 'attribute_name'),
        attribute_value=pulumi.get(__response__, 'attribute_value'),
        childrens=pulumi.get(__response__, 'childrens'),
        condition_type=pulumi.get(__response__, 'condition_type'),
        description=pulumi.get(__response__, 'description'),
        dictionary_name=pulumi.get(__response__, 'dictionary_name'),
        dictionary_value=pulumi.get(__response__, 'dictionary_value'),
        id=pulumi.get(__response__, 'id'),
        is_negate=pulumi.get(__response__, 'is_negate'),
        name=pulumi.get(__response__, 'name'),
        operator=pulumi.get(__response__, 'operator')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .active_directory_add_groups import *
from .active_directory_join_domain_with_all_nodes import *
from .active_directory_join_point import *
from .certificate_authentication_profile import *
from .endpoint import *
from .endpoint_custom_attribute import *
from .endpoint_identity_group import *
from .get_active_directory_groups_by_domain import *
from .get_active_directory_join_point import *
from .get_certificate_authentication_profile import *
from .get_endpoint import *
from .get_endpoint_custom_attribute import *
from .get_endpoint_identity_group import *
from .get_identity_source_sequence import *
from .get_internal_user import *
from .get_user_identity_group import *
from .identity_source_sequence import *
from .internal_user import *
from .user_identity_group import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConditionArgs', 'Condition']

@pulumi.input_type
class ConditionArgs:
    def __init__(__self__, *,
                 condition_type: pulumi.Input[_builtins.str],
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Condition resource.
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
               `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        :param pulumi.Input[_builtins.str] attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]] childrens: List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        :param pulumi.Input[_builtins.str] description: Condition description
        :param pulumi.Input[_builtins.str] dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] name: Condition name
        :param pulumi.Input[_builtins.str] operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        pulumi.set(__self__, "condition_type", condition_type)
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> pulumi.Input[_builtins.str]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
        `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        """
        return pulumi.get(self, "condition_type")

    @condition_type.setter
    def condition_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "condition_type", value)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @attribute_value.setter
    def attribute_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_value", value)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]]:
        """
        List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @childrens.setter
    def childrens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]]):
        pulumi.set(self, "childrens", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @dictionary_name.setter
    def dictionary_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dictionary_name", value)

    @_builtins.property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @dictionary_value.setter
    def dictionary_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dictionary_value", value)

    @_builtins.property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @is_negate.setter
    def is_negate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_negate", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")

    @operator.setter
    def operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "operator", value)


@pulumi.input_type
class _ConditionState:
    def __init__(__self__, *,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Condition resources.
        :param pulumi.Input[_builtins.str] attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]] childrens: List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
               `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        :param pulumi.Input[_builtins.str] description: Condition description
        :param pulumi.Input[_builtins.str] dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] name: Condition name
        :param pulumi.Input[_builtins.str] operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        if attribute_name is not None:
            pulumi.set(__self__, "attribute_name", attribute_name)
        if attribute_value is not None:
            pulumi.set(__self__, "attribute_value", attribute_value)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if condition_type is not None:
            pulumi.set(__self__, "condition_type", condition_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dictionary_name is not None:
            pulumi.set(__self__, "dictionary_name", dictionary_name)
        if dictionary_value is not None:
            pulumi.set(__self__, "dictionary_value", dictionary_value)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operator is not None:
            pulumi.set(__self__, "operator", operator)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @attribute_name.setter
    def attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @attribute_value.setter
    def attribute_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "attribute_value", value)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]]:
        """
        List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @childrens.setter
    def childrens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConditionChildrenArgs']]]]):
        pulumi.set(self, "childrens", value)

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
        `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        """
        return pulumi.get(self, "condition_type")

    @condition_type.setter
    def condition_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @dictionary_name.setter
    def dictionary_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dictionary_name", value)

    @_builtins.property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @dictionary_value.setter
    def dictionary_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dictionary_value", value)

    @_builtins.property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @is_negate.setter
    def is_negate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_negate", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")

    @operator.setter
    def operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "operator", value)


@pulumi.type_token("ise:networkaccess/condition:Condition")
class Condition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConditionChildrenArgs', 'ConditionChildrenArgsDict']]]]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a Network Access Condition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.networkaccess.Condition("example",
            name="Cond1",
            description="My description",
            condition_type="LibraryConditionAttributes",
            is_negate=False,
            attribute_name="EapAuthentication",
            attribute_value="EAP-TLS",
            dictionary_name="Network Access",
            operator="equals")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:networkaccess/condition:Condition example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConditionChildrenArgs', 'ConditionChildrenArgsDict']]]] childrens: List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
               `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        :param pulumi.Input[_builtins.str] description: Condition description
        :param pulumi.Input[_builtins.str] dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] name: Condition name
        :param pulumi.Input[_builtins.str] operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConditionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a Network Access Condition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.networkaccess.Condition("example",
            name="Cond1",
            description="My description",
            condition_type="LibraryConditionAttributes",
            is_negate=False,
            attribute_name="EapAuthentication",
            attribute_value="EAP-TLS",
            dictionary_name="Network Access",
            operator="equals")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:networkaccess/condition:Condition example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param ConditionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConditionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConditionChildrenArgs', 'ConditionChildrenArgsDict']]]]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 operator: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConditionArgs.__new__(ConditionArgs)

            __props__.__dict__["attribute_name"] = attribute_name
            __props__.__dict__["attribute_value"] = attribute_value
            __props__.__dict__["childrens"] = childrens
            if condition_type is None and not opts.urn:
                raise TypeError("Missing required property 'condition_type'")
            __props__.__dict__["condition_type"] = condition_type
            __props__.__dict__["description"] = description
            __props__.__dict__["dictionary_name"] = dictionary_name
            __props__.__dict__["dictionary_value"] = dictionary_value
            __props__.__dict__["is_negate"] = is_negate
            __props__.__dict__["name"] = name
            __props__.__dict__["operator"] = operator
        super(Condition, __self__).__init__(
            'ise:networkaccess/condition:Condition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
            attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
            childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConditionChildrenArgs', 'ConditionChildrenArgsDict']]]]] = None,
            condition_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
            dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
            is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            operator: Optional[pulumi.Input[_builtins.str]] = None) -> 'Condition':
        """
        Get an existing Condition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ConditionChildrenArgs', 'ConditionChildrenArgsDict']]]] childrens: List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
               `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        :param pulumi.Input[_builtins.str] description: Condition description
        :param pulumi.Input[_builtins.str] dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] name: Condition name
        :param pulumi.Input[_builtins.str] operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConditionState.__new__(_ConditionState)

        __props__.__dict__["attribute_name"] = attribute_name
        __props__.__dict__["attribute_value"] = attribute_value
        __props__.__dict__["childrens"] = childrens
        __props__.__dict__["condition_type"] = condition_type
        __props__.__dict__["description"] = description
        __props__.__dict__["dictionary_name"] = dictionary_name
        __props__.__dict__["dictionary_value"] = dictionary_value
        __props__.__dict__["is_negate"] = is_negate
        __props__.__dict__["name"] = name
        __props__.__dict__["operator"] = operator
        return Condition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="attributeName")
    def attribute_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "attribute_name")

    @_builtins.property
    @pulumi.getter(name="attributeValue")
    def attribute_value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "attribute_value")

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> pulumi.Output[Optional[Sequence['outputs.ConditionChildren']]]:
        """
        List of child conditions. `condition_type` must be one of `LibraryConditionAndBlock` or `LibraryConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> pulumi.Output[_builtins.str]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `LibraryConditionAndBlock`,
        `LibraryConditionAttributes`, `LibraryConditionOrBlock`
        """
        return pulumi.get(self, "condition_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="dictionaryName")
    def dictionary_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "dictionary_name")

    @_builtins.property
    @pulumi.getter(name="dictionaryValue")
    def dictionary_value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "dictionary_value")

    @_builtins.property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def operator(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "operator")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PolicySetArgs', 'PolicySet']

@pulumi.input_type
class PolicySetArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[_builtins.str],
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]] = None,
                 condition_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_id: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 condition_operator: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_proxy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PolicySet resource.
        :param pulumi.Input[_builtins.str] service_name: Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        :param pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] condition_attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[_builtins.str] condition_dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] condition_dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.str] condition_id: UUID for condition
        :param pulumi.Input[_builtins.bool] condition_is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] condition_operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
               `ConditionOrBlock`, `ConditionReference`
        :param pulumi.Input[_builtins.bool] default: Indicates if this policy set is the default one
        :param pulumi.Input[_builtins.str] description: The description of the policy set
        :param pulumi.Input[_builtins.bool] is_proxy: Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        :param pulumi.Input[_builtins.str] name: Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] state: The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
               `monitor`
        """
        pulumi.set(__self__, "service_name", service_name)
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if condition_attribute_name is not None:
            pulumi.set(__self__, "condition_attribute_name", condition_attribute_name)
        if condition_attribute_value is not None:
            pulumi.set(__self__, "condition_attribute_value", condition_attribute_value)
        if condition_dictionary_name is not None:
            pulumi.set(__self__, "condition_dictionary_name", condition_dictionary_name)
        if condition_dictionary_value is not None:
            pulumi.set(__self__, "condition_dictionary_value", condition_dictionary_value)
        if condition_id is not None:
            pulumi.set(__self__, "condition_id", condition_id)
        if condition_is_negate is not None:
            pulumi.set(__self__, "condition_is_negate", condition_is_negate)
        if condition_operator is not None:
            pulumi.set(__self__, "condition_operator", condition_operator)
        if condition_type is not None:
            pulumi.set(__self__, "condition_type", condition_type)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_proxy is not None:
            pulumi.set(__self__, "is_proxy", is_proxy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rank is not None:
            pulumi.set(__self__, "rank", rank)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @childrens.setter
    def childrens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]]):
        pulumi.set(self, "childrens", value)

    @_builtins.property
    @pulumi.getter(name="conditionAttributeName")
    def condition_attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "condition_attribute_name")

    @condition_attribute_name.setter
    def condition_attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="conditionAttributeValue")
    def condition_attribute_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "condition_attribute_value")

    @condition_attribute_value.setter
    def condition_attribute_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_attribute_value", value)

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryName")
    def condition_dictionary_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "condition_dictionary_name")

    @condition_dictionary_name.setter
    def condition_dictionary_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_dictionary_name", value)

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryValue")
    def condition_dictionary_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "condition_dictionary_value")

    @condition_dictionary_value.setter
    def condition_dictionary_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_dictionary_value", value)

    @_builtins.property
    @pulumi.getter(name="conditionId")
    def condition_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UUID for condition
        """
        return pulumi.get(self, "condition_id")

    @condition_id.setter
    def condition_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_id", value)

    @_builtins.property
    @pulumi.getter(name="conditionIsNegate")
    def condition_is_negate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "condition_is_negate")

    @condition_is_negate.setter
    def condition_is_negate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "condition_is_negate", value)

    @_builtins.property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "condition_operator")

    @condition_operator.setter
    def condition_operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_operator", value)

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
        `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @condition_type.setter
    def condition_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_type", value)

    @_builtins.property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if this policy set is the default one
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "default", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the policy set
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isProxy")
    def is_proxy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        """
        return pulumi.get(self, "is_proxy")

    @is_proxy.setter
    def is_proxy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_proxy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def rank(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @rank.setter
    def rank(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rank", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
        `monitor`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class _PolicySetState:
    def __init__(__self__, *,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]] = None,
                 condition_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_id: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 condition_operator: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_proxy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PolicySet resources.
        :param pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] condition_attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[_builtins.str] condition_dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] condition_dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.str] condition_id: UUID for condition
        :param pulumi.Input[_builtins.bool] condition_is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] condition_operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
               `ConditionOrBlock`, `ConditionReference`
        :param pulumi.Input[_builtins.bool] default: Indicates if this policy set is the default one
        :param pulumi.Input[_builtins.str] description: The description of the policy set
        :param pulumi.Input[_builtins.bool] is_proxy: Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        :param pulumi.Input[_builtins.str] name: Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] service_name: Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        :param pulumi.Input[_builtins.str] state: The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
               `monitor`
        """
        if childrens is not None:
            pulumi.set(__self__, "childrens", childrens)
        if condition_attribute_name is not None:
            pulumi.set(__self__, "condition_attribute_name", condition_attribute_name)
        if condition_attribute_value is not None:
            pulumi.set(__self__, "condition_attribute_value", condition_attribute_value)
        if condition_dictionary_name is not None:
            pulumi.set(__self__, "condition_dictionary_name", condition_dictionary_name)
        if condition_dictionary_value is not None:
            pulumi.set(__self__, "condition_dictionary_value", condition_dictionary_value)
        if condition_id is not None:
            pulumi.set(__self__, "condition_id", condition_id)
        if condition_is_negate is not None:
            pulumi.set(__self__, "condition_is_negate", condition_is_negate)
        if condition_operator is not None:
            pulumi.set(__self__, "condition_operator", condition_operator)
        if condition_type is not None:
            pulumi.set(__self__, "condition_type", condition_type)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_proxy is not None:
            pulumi.set(__self__, "is_proxy", is_proxy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rank is not None:
            pulumi.set(__self__, "rank", rank)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @childrens.setter
    def childrens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicySetChildrenArgs']]]]):
        pulumi.set(self, "childrens", value)

    @_builtins.property
    @pulumi.getter(name="conditionAttributeName")
    def condition_attribute_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "condition_attribute_name")

    @condition_attribute_name.setter
    def condition_attribute_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_attribute_name", value)

    @_builtins.property
    @pulumi.getter(name="conditionAttributeValue")
    def condition_attribute_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "condition_attribute_value")

    @condition_attribute_value.setter
    def condition_attribute_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_attribute_value", value)

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryName")
    def condition_dictionary_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "condition_dictionary_name")

    @condition_dictionary_name.setter
    def condition_dictionary_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_dictionary_name", value)

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryValue")
    def condition_dictionary_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "condition_dictionary_value")

    @condition_dictionary_value.setter
    def condition_dictionary_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_dictionary_value", value)

    @_builtins.property
    @pulumi.getter(name="conditionId")
    def condition_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UUID for condition
        """
        return pulumi.get(self, "condition_id")

    @condition_id.setter
    def condition_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_id", value)

    @_builtins.property
    @pulumi.getter(name="conditionIsNegate")
    def condition_is_negate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "condition_is_negate")

    @condition_is_negate.setter
    def condition_is_negate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "condition_is_negate", value)

    @_builtins.property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "condition_operator")

    @condition_operator.setter
    def condition_operator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_operator", value)

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
        `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @condition_type.setter
    def condition_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "condition_type", value)

    @_builtins.property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if this policy set is the default one
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "default", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the policy set
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isProxy")
    def is_proxy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        """
        return pulumi.get(self, "is_proxy")

    @is_proxy.setter
    def is_proxy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_proxy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def rank(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @rank.setter
    def rank(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rank", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
        `monitor`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("ise:deviceadmin/policySet:PolicySet")
class PolicySet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicySetChildrenArgs', 'PolicySetChildrenArgsDict']]]]] = None,
                 condition_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_id: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 condition_operator: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_proxy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a Device Admin Policy Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.PolicySet("example",
            name="PolicySet1",
            description="My description",
            is_proxy=False,
            rank=0,
            service_name="Default Device Admin",
            state="enabled",
            condition_type="ConditionAttributes",
            condition_is_negate=False,
            condition_attribute_name="Location",
            condition_attribute_value="All Locations",
            condition_dictionary_name="DEVICE",
            condition_operator="equals")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:deviceadmin/policySet:PolicySet example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicySetChildrenArgs', 'PolicySetChildrenArgsDict']]]] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] condition_attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[_builtins.str] condition_dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] condition_dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.str] condition_id: UUID for condition
        :param pulumi.Input[_builtins.bool] condition_is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] condition_operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
               `ConditionOrBlock`, `ConditionReference`
        :param pulumi.Input[_builtins.bool] default: Indicates if this policy set is the default one
        :param pulumi.Input[_builtins.str] description: The description of the policy set
        :param pulumi.Input[_builtins.bool] is_proxy: Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        :param pulumi.Input[_builtins.str] name: Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] service_name: Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        :param pulumi.Input[_builtins.str] state: The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
               `monitor`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicySetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a Device Admin Policy Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.PolicySet("example",
            name="PolicySet1",
            description="My description",
            is_proxy=False,
            rank=0,
            service_name="Default Device Admin",
            state="enabled",
            condition_type="ConditionAttributes",
            condition_is_negate=False,
            condition_attribute_name="Location",
            condition_attribute_value="All Locations",
            condition_dictionary_name="DEVICE",
            condition_operator="equals")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import ise:deviceadmin/policySet:PolicySet example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param PolicySetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicySetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicySetChildrenArgs', 'PolicySetChildrenArgsDict']]]]] = None,
                 condition_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_id: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
                 condition_operator: Optional[pulumi.Input[_builtins.str]] = None,
                 condition_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_proxy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rank: Optional[pulumi.Input[_builtins.int]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicySetArgs.__new__(PolicySetArgs)

            __props__.__dict__["childrens"] = childrens
            __props__.__dict__["condition_attribute_name"] = condition_attribute_name
            __props__.__dict__["condition_attribute_value"] = condition_attribute_value
            __props__.__dict__["condition_dictionary_name"] = condition_dictionary_name
            __props__.__dict__["condition_dictionary_value"] = condition_dictionary_value
            __props__.__dict__["condition_id"] = condition_id
            __props__.__dict__["condition_is_negate"] = condition_is_negate
            __props__.__dict__["condition_operator"] = condition_operator
            __props__.__dict__["condition_type"] = condition_type
            __props__.__dict__["default"] = default
            __props__.__dict__["description"] = description
            __props__.__dict__["is_proxy"] = is_proxy
            __props__.__dict__["name"] = name
            __props__.__dict__["rank"] = rank
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["state"] = state
        super(PolicySet, __self__).__init__(
            'ise:deviceadmin/policySet:PolicySet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            childrens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicySetChildrenArgs', 'PolicySetChildrenArgsDict']]]]] = None,
            condition_attribute_name: Optional[pulumi.Input[_builtins.str]] = None,
            condition_attribute_value: Optional[pulumi.Input[_builtins.str]] = None,
            condition_dictionary_name: Optional[pulumi.Input[_builtins.str]] = None,
            condition_dictionary_value: Optional[pulumi.Input[_builtins.str]] = None,
            condition_id: Optional[pulumi.Input[_builtins.str]] = None,
            condition_is_negate: Optional[pulumi.Input[_builtins.bool]] = None,
            condition_operator: Optional[pulumi.Input[_builtins.str]] = None,
            condition_type: Optional[pulumi.Input[_builtins.str]] = None,
            default: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            is_proxy: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            rank: Optional[pulumi.Input[_builtins.int]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'PolicySet':
        """
        Get an existing PolicySet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicySetChildrenArgs', 'PolicySetChildrenArgsDict']]]] childrens: List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        :param pulumi.Input[_builtins.str] condition_attribute_name: Dictionary attribute name
        :param pulumi.Input[_builtins.str] condition_attribute_value: Attribute value for condition. Value type is specified in dictionary object.
        :param pulumi.Input[_builtins.str] condition_dictionary_name: Dictionary name
        :param pulumi.Input[_builtins.str] condition_dictionary_value: Dictionary value
        :param pulumi.Input[_builtins.str] condition_id: UUID for condition
        :param pulumi.Input[_builtins.bool] condition_is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[_builtins.str] condition_operator: Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
               `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
               `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        :param pulumi.Input[_builtins.str] condition_type: Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
               additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
               `ConditionOrBlock`, `ConditionReference`
        :param pulumi.Input[_builtins.bool] default: Indicates if this policy set is the default one
        :param pulumi.Input[_builtins.str] description: The description of the policy set
        :param pulumi.Input[_builtins.bool] is_proxy: Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        :param pulumi.Input[_builtins.str] name: Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        :param pulumi.Input[_builtins.int] rank: The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        :param pulumi.Input[_builtins.str] service_name: Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        :param pulumi.Input[_builtins.str] state: The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
               `monitor`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicySetState.__new__(_PolicySetState)

        __props__.__dict__["childrens"] = childrens
        __props__.__dict__["condition_attribute_name"] = condition_attribute_name
        __props__.__dict__["condition_attribute_value"] = condition_attribute_value
        __props__.__dict__["condition_dictionary_name"] = condition_dictionary_name
        __props__.__dict__["condition_dictionary_value"] = condition_dictionary_value
        __props__.__dict__["condition_id"] = condition_id
        __props__.__dict__["condition_is_negate"] = condition_is_negate
        __props__.__dict__["condition_operator"] = condition_operator
        __props__.__dict__["condition_type"] = condition_type
        __props__.__dict__["default"] = default
        __props__.__dict__["description"] = description
        __props__.__dict__["is_proxy"] = is_proxy
        __props__.__dict__["name"] = name
        __props__.__dict__["rank"] = rank
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["state"] = state
        return PolicySet(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def childrens(self) -> pulumi.Output[Optional[Sequence['outputs.PolicySetChildren']]]:
        """
        List of child conditions. `condition_type` must be one of `ConditionAndBlock` or `ConditionOrBlock`.
        """
        return pulumi.get(self, "childrens")

    @_builtins.property
    @pulumi.getter(name="conditionAttributeName")
    def condition_attribute_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary attribute name
        """
        return pulumi.get(self, "condition_attribute_name")

    @_builtins.property
    @pulumi.getter(name="conditionAttributeValue")
    def condition_attribute_value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Attribute value for condition. Value type is specified in dictionary object.
        """
        return pulumi.get(self, "condition_attribute_value")

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryName")
    def condition_dictionary_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary name
        """
        return pulumi.get(self, "condition_dictionary_name")

    @_builtins.property
    @pulumi.getter(name="conditionDictionaryValue")
    def condition_dictionary_value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Dictionary value
        """
        return pulumi.get(self, "condition_dictionary_value")

    @_builtins.property
    @pulumi.getter(name="conditionId")
    def condition_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        UUID for condition
        """
        return pulumi.get(self, "condition_id")

    @_builtins.property
    @pulumi.getter(name="conditionIsNegate")
    def condition_is_negate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "condition_is_negate")

    @_builtins.property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Equality operator - Choices: `contains`, `endsWith`, `equals`, `greaterOrEquals`, `greaterThan`, `in`, `ipEquals`,
        `ipGreaterThan`, `ipLessThan`, `ipNotEquals`, `lessOrEquals`, `lessThan`, `matches`, `notContains`, `notEndsWith`,
        `notEquals`, `notIn`, `notStartsWith`, `startsWith`
        """
        return pulumi.get(self, "condition_operator")

    @_builtins.property
    @pulumi.getter(name="conditionType")
    def condition_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Indicates whether the record is the condition itself or a logical aggregation. Logical aggreation indicates that
        additional conditions are present under the children attribute. - Choices: `ConditionAndBlock`, `ConditionAttributes`,
        `ConditionOrBlock`, `ConditionReference`
        """
        return pulumi.get(self, "condition_type")

    @_builtins.property
    @pulumi.getter
    def default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if this policy set is the default one
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the policy set
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="isProxy")
    def is_proxy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag which indicates if the policy set service is of type 'Proxy Sequence' or 'Allowed Protocols'
        """
        return pulumi.get(self, "is_proxy")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Given name for the policy set, [Valid characters are alphanumerics, underscore, hyphen, space, period, parentheses]
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def rank(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The rank (priority) in relation to other policy sets. Lower rank is higher priority.
        """
        return pulumi.get(self, "rank")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        Policy set service identifier. 'Allowed Protocols' or 'Server Sequence'.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The state that the policy set is in. A disabled policy set cannot be matched. - Choices: `disabled`, `enabled`,
        `monitor`
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthorizationGlobalExceptionRuleUpdateRanksArgs', 'AuthorizationGlobalExceptionRuleUpdateRanks']

@pulumi.input_type
class AuthorizationGlobalExceptionRuleUpdateRanksArgs:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]] = None):
        """
        The set of arguments for constructing a AuthorizationGlobalExceptionRuleUpdateRanks resource.
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]:
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _AuthorizationGlobalExceptionRuleUpdateRanksState:
    def __init__(__self__, *,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering AuthorizationGlobalExceptionRuleUpdateRanks resources.
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]:
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRanks:AuthorizationGlobalExceptionRuleUpdateRanks")
class AuthorizationGlobalExceptionRuleUpdateRanks(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None,
                 __props__=None):
        """
        This resource is used to bulk update rank field in device admin authorization global exception rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_global_exception_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationGlobalExceptionRuleUpdateRanks("example", rules=[{
            "id": "3741aca3-db08-4899-af73-2e3f65ec31e1",
            "rank": 0,
        }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AuthorizationGlobalExceptionRuleUpdateRanksArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource is used to bulk update rank field in device admin authorization global exception rule. It serves as a workaround for the ISE API/Backend limitation which restricts rank assignments to a strictly incremental sequence. By utilizing this resource and device_admin_authorization_global_exception_rule resource, you can bypass the APIs limitation. Creation of this resource is performing PUT operation (Update) and it only tracks rank field. When this resource is destroyed, no action is performed on ISE and resource is just removed from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.AuthorizationGlobalExceptionRuleUpdateRanks("example", rules=[{
            "id": "3741aca3-db08-4899-af73-2e3f65ec31e1",
            "rank": 0,
        }])
        ```

        :param str resource_name: The name of the resource.
        :param AuthorizationGlobalExceptionRuleUpdateRanksArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthorizationGlobalExceptionRuleUpdateRanksArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthorizationGlobalExceptionRuleUpdateRanksArgs.__new__(AuthorizationGlobalExceptionRuleUpdateRanksArgs)

            __props__.__dict__["rules"] = rules
        super(AuthorizationGlobalExceptionRuleUpdateRanks, __self__).__init__(
            'ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRanks:AuthorizationGlobalExceptionRuleUpdateRanks',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationGlobalExceptionRuleUpdateRanksRuleArgs', 'AuthorizationGlobalExceptionRuleUpdateRanksRuleArgsDict']]]]] = None) -> 'AuthorizationGlobalExceptionRuleUpdateRanks':
        """
        Get an existing AuthorizationGlobalExceptionRuleUpdateRanks resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthorizationGlobalExceptionRuleUpdateRanksState.__new__(_AuthorizationGlobalExceptionRuleUpdateRanksState)

        __props__.__dict__["rules"] = rules
        return AuthorizationGlobalExceptionRuleUpdateRanks(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Optional[Sequence['outputs.AuthorizationGlobalExceptionRuleUpdateRanksRule']]]:
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DeviceIp',
    'GetDeviceIpResult',
]

@pulumi.output_type
class DeviceIp(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipaddressExclude":
            suggest = "ipaddress_exclude"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeviceIp. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeviceIp.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeviceIp.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ipaddress: _builtins.str,
                 ipaddress_exclude: Optional[_builtins.str] = None,
                 mask: Optional[_builtins.str] = None):
        """
        :param _builtins.str ipaddress: It can be either single ip address or ip range address
        :param _builtins.str ipaddress_exclude: It can be either single ip address or ip range address
        :param _builtins.str mask: Subnet mask length
        """
        pulumi.set(__self__, "ipaddress", ipaddress)
        if ipaddress_exclude is not None:
            pulumi.set(__self__, "ipaddress_exclude", ipaddress_exclude)
        if mask is not None:
            pulumi.set(__self__, "mask", mask)

    @_builtins.property
    @pulumi.getter
    def ipaddress(self) -> _builtins.str:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress")

    @_builtins.property
    @pulumi.getter(name="ipaddressExclude")
    def ipaddress_exclude(self) -> Optional[_builtins.str]:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress_exclude")

    @_builtins.property
    @pulumi.getter
    def mask(self) -> Optional[_builtins.str]:
        """
        Subnet mask length
        """
        return pulumi.get(self, "mask")


@pulumi.output_type
class GetDeviceIpResult(dict):
    def __init__(__self__, *,
                 ipaddress: _builtins.str,
                 ipaddress_exclude: _builtins.str,
                 mask: _builtins.str):
        """
        :param _builtins.str ipaddress: It can be either single ip address or ip range address
        :param _builtins.str ipaddress_exclude: It can be either single ip address or ip range address
        :param _builtins.str mask: Subnet mask length
        """
        pulumi.set(__self__, "ipaddress", ipaddress)
        pulumi.set(__self__, "ipaddress_exclude", ipaddress_exclude)
        pulumi.set(__self__, "mask", mask)

    @_builtins.property
    @pulumi.getter
    def ipaddress(self) -> _builtins.str:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress")

    @_builtins.property
    @pulumi.getter(name="ipaddressExclude")
    def ipaddress_exclude(self) -> _builtins.str:
        """
        It can be either single ip address or ip range address
        """
        return pulumi.get(self, "ipaddress_exclude")

    @_builtins.property
    @pulumi.getter
    def mask(self) -> _builtins.str:
        """
        Subnet mask length
        """
        return pulumi.get(self, "mask")


